@@ -1,23 +1,6 @@
-'''
-
-Interaction with metadata and properties
-
-Copyright (C) 2018-2020 Vanessa Sochat.
-
-This program is free software: you can redistribute it and/or modify it
-under the terms of the GNU Affero General Public License as published by
-the Free Software Foundation, either version 3 of the License, or (at your
-option) any later version.
-
-This program is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
-License for more details.
-
-You should have received a copy of the GNU Affero General Public License
-along with this program.  If not, see <https://www.gnu.org/licenses/>.
-
-'''
+__author__ = "Vanessa Sochat"
+__copyright__ = "Copyright 2018-2021, Vanessa Sochat"
+__license__ = "MPL 2.0"
 
 from schemaorg.logger import bot
 import os
